@@ -1046,8 +1046,6 @@ int iface_setup_from_boot_context(struct iface_rec *iface,
 			return 0;
 		}
 	} else if (strlen(context->iface)) {
-/* this ifdef is only temp until distros and firmwares are updated */
-#ifdef OFFLOAD_BOOT_SUPPORTED
 		char transport_name[ISCSI_TRANSPORT_NAME_MAXLEN];
 		int rc;
 
@@ -1075,9 +1073,6 @@ int iface_setup_from_boot_context(struct iface_rec *iface,
 		}
 
 		strlcpy(iface->netdev, context->iface, sizeof(iface->netdev));
-#else
-		return 0;
-#endif
 	} else
 		return 0;
 
