@@ -40,6 +40,7 @@
 #include "host.h"
 #include "iscsi_err.h"
 #include "flashnode.h"
+#include "iscsi_util.h"
 
 /*
  * TODO: remove the _DIR defines and search for subsys dirs like
@@ -1416,8 +1417,8 @@ int iscsi_sysfs_get_sessioninfo_by_id(struct session_info *info, char *session)
 	log_debug(7, "found targetname %s address %s pers address %s port %d "
 		 "pers port %d driver %s iface name %s ipaddress %s "
 		 "netdev %s hwaddress %s iname %s",
-		  info->targetname, info->address ? info->address : "NA",
-		  info->persistent_address ? info->persistent_address : "NA",
+		  info->targetname, info->address[0] ? info->address : "NA",
+		  info->persistent_address[0] ? info->persistent_address : "NA",
 		  info->port, info->persistent_port, info->iface.transport_name,
 		  info->iface.name, info->iface.ipaddress,
 		  info->iface.netdev, info->iface.hwaddress,
@@ -1929,18 +1930,41 @@ void iscsi_sysfs_set_queue_depth(void *data, int hostno, int target, int lun)
 void iscsi_sysfs_set_device_online(__attribute__((unused))void *data,
 				   int hostno, int target, int lun)
 {
-	char *write_buf = "running\n";
+	char *write_buf = "running\n", *state;
 	char id[NAME_SIZE];
 	int err;
 
 	snprintf(id, sizeof(id), "%d:0:%d:%d", hostno, target, lun);
 	log_debug(4, "online device %s", id);
 
+	state = sysfs_get_value(id, SCSI_SUBSYS, "state");
+	if (!state) {
+		log_error("Could not read state for LUN %s\n", id);
+		goto set_state;
+	}
+
+	if (!strcmp(state, "running"))
+		goto done;
+	/*
+	 * The kernel can start to perform session level recovery cleanup
+	 * any time after the conn start call, so we only want to change the
+	 * state if we are in one of the offline states.
+	 */
+	if (strcmp(state, "offline") && strcmp(state, "transport-offline")) {
+		log_debug(4, "Dev not offline. Skip onlining %s", id);
+		goto done;
+	}
+
+set_state:
 	err = sysfs_set_param(id, SCSI_SUBSYS, "state", write_buf,
 			      strlen(write_buf));
 	if (err && err != EINVAL)
 		/* we should read the state */
 		log_error("Could not online LUN %d err %d.", lun, err);
+
+done:
+	if (state)
+		free(state);
 }
 
 void iscsi_sysfs_rescan_device(__attribute__((unused))void *data,
@@ -1971,6 +1995,12 @@ pid_t iscsi_sysfs_scan_host(int hostno, int async, int autoscan)
 		/* child */
 		log_debug(4, "scanning host%d", hostno);
 
+		/*
+		 * The return value of init_thread_io_flusher would not
+		 * affect the scan flow, so just ignore it.
+		 */
+		set_thread_io_flusher(0);
+
 		snprintf(id, sizeof(id), ISCSI_HOST_ID, hostno);
 		sysfs_set_param(id, SCSI_HOST_SUBSYS, "scan", write_buf,
 				strlen(write_buf));
